//*
// 媒体共享模块
// */

import Loger from "../Loger";
import Ape from "./Ape";
import xdysdk from "libs/xdysdk";
import $ from "jquery";
import ClassDataProxy from "proxy/ClassDataProxy";
import FlashToolComponet from "libs/FlashToolComponet";
import HLSPlayer from 'tinyhls';
import MD5 from "md5";
import UIControlApe from './UIControlApe';
import ErrorApe from './ErrorApe';
import MediaControlBarApe from './MediaControlBarApe';

let loger = Loger.getLoger('PC-MediaShareApe');

class MediaShareApe extends Ape {
  constructor() {
    super();
    this.h5HLSplayer = null;//HLS播放
    this.currPlayMediaId = 0;//当前选择的文件
    this.mediaShareFileList = {};//媒体数据列表
    this.controlBar = new MediaControlBarApe();
    this.controlBar.controlCallback = this._controlCallback.bind(this);

    this.addEvent();
    this._hideMediaShareBox();
  }

  init() {
    //布局
    $(window).on('resize', this.onWindowResize.bind(this));
    //UI按钮点击事件
    //$("#mediaFile").on("change", this._uploadFile.bind(this));//左侧的上传文件
    $("#mediaFileBtn").on("change", this._uploadFile.bind(this));//上传文件
    $("#mediaListOut").on("click", this._openListHandler.bind(this));//打开列表
    $("#closeMediaList").on("click", this._closeListHandler.bind(this));//关闭列表
  }

  addEvent() {
    xdysdk.on("class_get_info_success", this._classGetInfoSuccessHandler.bind(this));//课堂数据获取成功之后就可以创建媒体共享的flash或H5播放器
    xdysdk.on("media_stop_publish", this._mediaStopPublishHandler.bind(this));
    xdysdk.on("class_join_success", this._classJoinSuccessHandler.bind(this));

    xdysdk.on("media_shared_update", this._onMediaShareUpdateHanlder.bind(this));//媒体更新
    xdysdk.on("media_shared_delete", this._onMediaShareDeleteHanlder.bind(this));//媒体删除
  }

  creatHLSPlayer() {
    loger.log('媒体共享录制回放->创建h5播放器');
    //创建h5播放器
    $('.h5MediaShareBox').show();
    let video = document.getElementById('h5MediaShare');
    this.h5HLSplayer = new HLSPlayer(video);
    this.h5HLSplayer.divName = 'h5MediaShare';
    this.h5HLSplayer.isMobile = true;//按移动端播放处理，使用原生的video
    this.h5HLSplayer.status = MediaShareApe.STOP;
    $("#h5MediaShare")[0].poster = "";//不需要背景图片

    //给控制条绑定video
    this.controlBar.video = video;
  }

  //事件监听-----------
  _classGetInfoSuccessHandler(_data) {
    this.init();
    this.creatHLSPlayer()
  }

  //停止当前的所有媒体共享
  _mediaStopPublishHandler() {
    if (ClassDataProxy.userRole == ClassDataProxy.USER_HOST) {
      loger.log('停止当前的所有媒体共享->');
      if (this.currPlayMediaId > 0) {
        this._stopMeidaShare(this.currPlayMediaId);
      }
    }
  }

  //监听控制条消息
  _controlCallback(_callBackData) {
    if (ClassDataProxy.userRole != ClassDataProxy.USER_HOST || ClassDataProxy.isRecordPlayBack) {
      loger.log("媒体共享播放器监听控制->录制回放和不是老师不处理");
      return;
    }
    loger.log("媒体共享播放器监听控制->", _callBackData);
    if (_callBackData) {
      //{"action":"pause","data":{"seek":36.027015,"mediaVolume":60}}
      switch (_callBackData.action) {
        case MediaControlBarApe.STOP:
          if (this.h5HLSplayer && this.h5HLSplayer.mediaId > 0) {
            this._updateMeidaShare(this.h5HLSplayer.mediaId, 0, _callBackData.data.seek, _callBackData.data.mediaVolume);
          }
          break;
        case MediaControlBarApe.PLAY:
          if (this.h5HLSplayer && this.h5HLSplayer.mediaId > 0) {
            this._updateMeidaShare(this.h5HLSplayer.mediaId, 1, _callBackData.data.seek, _callBackData.data.mediaVolume);
          }
          break;
        case MediaControlBarApe.PAUSE:
          if (this.h5HLSplayer && this.h5HLSplayer.mediaId > 0) {
            this._updateMeidaShare(this.h5HLSplayer.mediaId, 2, _callBackData.data.seek, _callBackData.data.mediaVolume);
          }
          break;
        default:
          break;
      }
    }
  }

  _classJoinSuccessHandler(_data) {
    if (_data.userRole == ClassDataProxy.USER_HOST && !ClassDataProxy.isRecordPlayBack) {
      //如果是老师端，需要开启定时同步数据的状态
      if (this.controlBar) {
        this.controlBar.isOpenUpdateStatusInfo = true;
      }
      $("#mediaShareBoxMask").hide();
    } else {
      $("#mediaUpLoadOut").hide();//上传按钮的父级div
      $("#mediaFile").hide();
      $("#mediaListOut").hide();
      //媒体共享区域的遮罩层，身份不是老师的时候就显示
      $("#mediaShareBoxMask").show();
    }
    this.onWindowResize();
  }

  //舞台大小发生改变
  onWindowResize() {
    //loger.log("舞台大小发生改变");
  }

  //监听媒体更新消息
  _onMediaShareUpdateHanlder(_data) {
    loger.log("媒体模块收到SDK数据", _data);
    if (_data == null) {
      return;
    }
    this._updateListData(_data, "add");

    switch (_data.status) {
      case 0:
        //停止
        this._tryStopMediaHandler(_data.itemIdx);
        break;
      case 1:
        //播放
        this._playMediaHandler(_data.itemIdx);
        break;
      case 2:
        //暂停
        this._tryPauseMediaHandler(_data);
        break;
        break;
      default:
        break;
    }
  }

  //监听媒体删除消息
  _onMediaShareDeleteHanlder(_data) {
    loger.log("_onMediaShareDeleteHanlder", _data);
    this._updateListData(_data, "delete");
  }

  //更新媒体数据(包括更新和删除) _type='add' 添加
  _updateListData(_data, _type) {
    if (_type == "add" && _data) {
      //loger.log("添加文件数据", _data);
      this.mediaShareFileList[_data.itemIdx] = _data;
    } else {
      loger.log("删除媒体数据", _data.itemIdx);
      delete this.mediaShareFileList[_data.itemIdx];

      if (this.h5HLSplayer && this.h5HLSplayer.mediaId == _data.itemIdx) {
        UIControlApe.enabledBottomBar();
        UIControlApe.enabledLeftBar();
        UIControlApe.showBottomDocControlBar();
        this.currPlayMediaId = 0;
        this.h5HLSplayer.rtmpURL = '';
        this.h5HLSplayer.mediaId = 0;
        this.h5HLSplayer.nodeId = 0;
        this.h5HLSplayer.status = MediaShareApe.STOP;
        this.h5HLSplayer.stop();
        this.h5HLSplayer.pause();
        if (this.h5HLSplayer.video) {
          this.h5HLSplayer.video.src = "";
        }
        this.controlBar.stop();
        this._hideMediaShareBox();
      }
    }
    //更新文件列表
    this._updateDocListView();
  }

  //更新文件列表显示
  _updateDocListView() {
    $("#mediaFileContent").empty();
    //console.log("this.mediaList", this.mediaShareFileList);
    for (let i in this.mediaShareFileList) {
      if (this.mediaShareFileList[i].fileId) {
        let listItem = this._creatListItemDiv(i, this.mediaShareFileList[i].fileName, this.mediaShareFileList[i].itemIdx);
        $("#mediaFileContent").append(listItem);//添加到媒体列表中
      }
    }
  }

  //显示媒体区域
  _showMediaShareBox(_data) {
    loger.log('显示媒体区域');
    $("#mediaShareGroup").show();
    $("#mediaShareGroup").css("z-index", 4);
    //显示之后需要更新布局
    if (this.controlBar) {
      this.controlBar.onWindowResize();
    }
  }

  //隐藏媒体区域
  _hideMediaShareBox(_data) {
    loger.log('隐藏媒体区域');
    $("#mediaShareGroup").hide();
    $("#mediaShareGroup").css("z-index", -7);
  }

  //停止并且隐藏
  stopAndHide() {
    loger.log("停止并且隐藏-.stopAndHide")
    this._stopMeidaShare(this.currPlayMediaId);

    if (this.controlBar) {
      this.controlBar.stop();
    }
    this.currPlayMediaId = 0;
    this._hideMediaShareBox();
    this._closeListHandler();
  }

  //显示媒体列表
  _openListHandler() {
    this._emit(MediaShareApe.SCENE_MEDIA_SHARE_CHANGE, ClassDataProxy.SCENE_MEDIA_SHARE);
    UIControlApe.disEnabledBottomBar();
    UIControlApe.hideBottomDocControlBar();
    $("#mediaShareModal").show();
    $(".masker").show();
  }

  //关闭媒体列表
  _closeListHandler() {
    $("#mediaShareModal").hide();
    $(".masker").hide();
  }

  //上传文件
  _uploadFile(evt) {
    let fileItem = document.getElementById('mediaFileBtn').files[0];
    if (!fileItem) {
      loger.log("没有选择文件");
      return;
    }
    this._closeListHandler();
    console.log("fileItem.type=====", fileItem);
    let fileStr = fileItem.name;
    let fileValue = fileStr.split('.')[1];
    loger.log("文件名:" + fileItem.name + "->文件类型:" + fileItem.type);
    //目前最大支持50M  格式为jpg png pdf docx pptx xlsx
    //判断文件的大小
    if (fileItem.size > (70 * 1024 * 1024)) {
      ErrorApe.showError(ErrorApe.TYPE_3,ClassDataProxy.localConfig.fileError);
      return;
    }

    let fileName = fileItem.name.toLowerCase();
    //判断选择的文件类型
    if (fileName.lastIndexOf('.mp4') < 0) {
      ErrorApe.showError(ErrorApe.TYPE_3,ClassDataProxy.localConfig.mediaLayoutCont);
      return;
    }

    if (!ClassDataProxy.DOCServerIP) {
      loger.warn("媒体服务器地址无效，无法上传文件!");
      ErrorApe.showError(ErrorApe.TYPE_3,ClassDataProxy.localConfig.serverError);
      return
    }
    //上传时动画效果
    UIControlApe.showLoadingMask();
    UIControlApe.disEnabledDocBar();
    UIControlApe.disEnabledMediaBar();
    //UIControlApe.disEnabledLeftBar();
    //UIControlApe.disEnabledBottomBar();
    //UIControlApe.hideBottomDocControlBar();
    let timestamp = ClassDataProxy.creatTimestamp();
    let authId = MD5(ClassDataProxy.siteId + "" + timestamp);///authId	String MD5(siteId+timestamp)
    //console.log("authId:"+authId,"siteId:"+ClassDataProxy.siteId,"timestamp:"+timestamp);
    let fd = new FormData();
    fd.append("fileToUpload", fileItem);
    fd.append("siteID", ClassDataProxy.siteId);   //站点
    fd.append("createUserName", String(ClassDataProxy.userName));  //上传人姓名
    fd.append("createUserID", String(ClassDataProxy.nodeId));   //上传人ID
    fd.append("timestamp", String(timestamp)); //时间戳
    fd.append("authId", authId);  //上传时间
    fd.append("classId", String(ClassDataProxy.classId));  //课堂号

/*    let ipport = ClassDataProxy.DOCServerIP;
    if (ClassDataProxy.DOCServerPort) {
      ipport = ipport + ":" + ClassDataProxy.DOCServerPort;
    }
    let mediaUploadUrl = `http://${ipport}/DocSharing/sharedMediaUpload`;*/

    let ipport=ClassDataProxy.DOCServerIP;
    if( ClassDataProxy.DOCServerPort){
      ipport=ipport+":"+ClassDataProxy.DOCServerPort;
    }
    let mediaUploadUrl= `${ClassDataProxy.locationProtocol+ipport}/DocSharing/sharedMediaUpload`;


    $.ajax({
      type: "POST",
      url: mediaUploadUrl,
      processData: false,
      contentType: false,
      data: fd,
      xhr: function () {
        let xhr = $.ajaxSettings.xhr();
        if (xhr.upload) {
          xhr.upload.addEventListener("progress", function (evt) {
            let loaded = evt.loaded;	//已经上传大小情况
            let tot = evt.total;		//附件总大小
            let per = Math.floor(100 * loaded / tot);  //已经上传的百分比
            UIControlApe.updataLoadingMaskProgress(per);
          }, false);
          return xhr;
        }
      },
      success: function (data) {
        //loger.log("媒体服务器返回的媒体数据-.", data);
        UIControlApe.hideLoadingMask();
        UIControlApe.enabledDocBar();
        UIControlApe.enabledMediaBar();
        //UIControlApe.enabledLeftBar();
        //UIControlApe.enabledBottomBar();
        //UIControlApe.showBottomDocControlBar();
        this._uploadFileSuccess(data);
        $("#mediaFileBtn").val('');
      }.bind(this),
      error: function (data) {
        //UIControlApe.enabledLeftBar();
        //UIControlApe.enabledBottomBar();
        //UIControlApe.showBottomDocControlBar();
        UIControlApe.hideLoadingMask();
        UIControlApe.enabledDocBar();
        UIControlApe.enabledMediaBar();
        loger.warn(name + "->上传文件失败", data);
        ErrorApe.showError(ErrorApe.TYPE_3,name + "->" + ClassDataProxy.localConfig.uploaDocumentErr);
        $("#mediaFileBtn").val('')
      }
    });
  }

  //将上传文件的信息,传递给底层
  _uploadFileSuccess(msg) {
    loger.log("服务器返回的媒体信息->", msg);
    //{"code":0,"list":[{"name":"sintel (2).mp4","id":"7","url":"http://101.200.150.192:9090/media/h5dev/201706/1478111117/76303834c69cd86f6c6212ae3019b1d0.mp4"}]}
    /*
     //code
     0：成功
     1：不是上传请求
     2：编码错误
     3：无法解析请求内容
     4：没有上传文件，或者上传文件超过10个
     5：siteId 不能为空
     6：authId 错误
     7：文件类型不支持
     8：保存文件信息失败
     10：保存文件失败*/
    if (msg && msg.code == 0) {
      //返回的数据中是一个数组，支持多个上传，目前只处理一个上传的情况
      if (!msg.list || msg.list.length < 1) {
        loger.warn('上传文件返回的数据中数组没有数据', msg.list);
        return;
      }
      let item = msg.list[0];
      if (item && item.id) {
        //{"name":"sintel (2).mp4","id":"7","url":"http://101.200.150.192:9090/media/h5dev/201706/1478111117/76303834c69cd86f6c6212ae3019b1d0.mp4"}
        let fileInfo = {};
        fileInfo.fileId = item.id;    //媒体在数据库中的唯一id标识 默认值: null
        fileInfo.fileName = item.name;//媒体名字
        fileInfo.url = item.url;   //媒体绝对地址  默认值: null
        fileInfo.duration = parseInt(item.duration) || 0;
        xdysdk.api("mediaSharedUpload", fileInfo);
      } else {
        loger.warn("服务器返回的文件信息->不能同步-->id无效", msg.id);
        ErrorApe.showError(ErrorApe.TYPE_3,ClassDataProxy.localConfig.uploaDocumentErr);
      }
    } else {
      loger.warn("文档上传失败->", msg.code);
      ErrorApe.showError(ErrorApe.TYPE_3,'文档上传失败->code:' + msg.code);
    }
  }

  //点击列表中切换媒体
  _clickListToSwitchBtnHandler(evt) {
    let _itemIdx = parseInt(evt.target.id);
    let listItem = this.mediaShareFileList[_itemIdx];

    //切换视频之前先停止之前播放的文件
    this._stopMeidaShare(this.currPlayMediaId);
    this.currPlayMediaId = 0;

    loger.log('点击列表中切换媒体->播放列表中的媒体文件->', listItem);
    this._playMeidaShare(listItem.itemIdx);
    this._closeListHandler();//隐藏列表
  }

  //切换媒体，把要显示的媒体数据发送给SDK
  _playMediaHandler(_itemIdx) {
    let listItem = this.mediaShareFileList[_itemIdx];
    if (listItem) {
      // console.log('播放列表中的媒体文件->',listItem);
      this._showMediaShareBox();

      //用H5播放
      if (this.h5HLSplayer) {
        if (ClassDataProxy.currentSceneTableId != ClassDataProxy.SCENE_MEDIA_SHARE) {
          //录制回放的时候，如果收到播放的消息，但是当前没有切换到媒体模块，那么就停止播放
          loger.log('录制回放->但是当前没有切换到媒体模块->currentSceneTableId->' + ClassDataProxy.currentSceneTableId);
          this._tryStopMediaHandler(listItem.itemIdx);
          return;
        }

        UIControlApe.disEnabledBottomBar();
        UIControlApe.hideBottomDocControlBar();
        this.currPlayMediaId = listItem.itemIdx;

        //回放的时候只播放状态为1的，2暂停的不播放
        if (listItem.status == 1) {
          let seek = listItem.seek || 1;
          loger.log('收到媒体共享播放->seek->' + seek);

          //-----------------------------判断是否同步处理---------------------------------------------------
          //如果媒体已经在播放，并且是同一个文件，那么判断收到的消息中seek和当前的seek差值；
          if (this.h5HLSplayer.status == MediaShareApe.PLAY &&
            this.h5HLSplayer.rtmpURL == listItem.url) {
            let seekDistance = Math.abs(seek - this.controlBar.seekTime);
            let volumeDistance = Math.abs(this.controlBar.mediaVolume - listItem.mediaVolume);
            loger.warn('当前正在播放->seekTime：' + this.controlBar.seekTime, "seek:" + seek, "seekDistance:" + seekDistance);
            loger.warn('当前正在播放->当前音量：' + this.controlBar.mediaVolume, "新的音量值:" + listItem.mediaVolume);

            //如果两次的差值小于相差小于3秒并且音量值未发生改变
            if (seekDistance < 3 && volumeDistance == 0) {
              loger.warn("不需要seek");
              return;
            }else {
              this.h5HLSplayer.seek(seek);
              this.h5HLSplayer.status = MediaShareApe.PLAY;
              this.controlBar.duration=listItem.duration||0;
              this.controlBar.seek(seek);
              this.controlBar.changeVolume(listItem.mediaVolume);
              return;
            }
          }
          //-----------------------------判断是否同步处理-END-------------------------------------------------------

          this.h5HLSplayer.rtmpURL = listItem.url;
          this.h5HLSplayer.nodeId = listItem.fromNodeId;
          this.h5HLSplayer.mediaId = listItem.itemIdx;
          this.h5HLSplayer.play(listItem.url, HLSPlayer.MODE_VOD, seek);
          this.h5HLSplayer.seek(seek);
          this.h5HLSplayer.status = MediaShareApe.PLAY;
          this.controlBar.duration=listItem.duration||0;
          this.controlBar.play(seek);
          this.controlBar.changeVolume(listItem.mediaVolume);
        }
      }
    }

  }

  //暂停
  _tryPauseMediaHandler(_data) {
    if (!_data) {
      return;
    }
    loger.log("_tryPauseMediaHandler", _data)
    let listItem = this.mediaShareFileList[_data.itemIdx];
    if (listItem) {
      // loger.log('播放列表中的媒体文件->',listItem);
      this._showMediaShareBox();
      ////录制回放使用H5播放
      if (this.h5HLSplayer) {
        if (ClassDataProxy.currentSceneTableId != ClassDataProxy.SCENE_MEDIA_SHARE) {
          //录制回放的时候，如果收到播放的消息，但是当前没有切换到媒体模块，那么就停止播放
          loger.log('录制回放->但是当前没有切换到媒体模块->currentSceneTableId->' + ClassDataProxy.currentSceneTableId);
          this._tryStopMediaHandler(listItem.itemIdx);
          return;
        }

        UIControlApe.disEnabledBottomBar();
        UIControlApe.hideBottomDocControlBar();
        this.currPlayMediaId = listItem.itemIdx;

        //暂停
        if (listItem.status == 2) {
          let seek = listItem.seek || 1;
          loger.log('收到媒体共享暂停->seek->' + seek);
          this.h5HLSplayer.rtmpURL = listItem.url;
          this.h5HLSplayer.nodeId = listItem.fromNodeId;
          this.h5HLSplayer.mediaId = listItem.itemIdx;

          //this.h5HLSplayer.play(listItem.url, HLSPlayer.MODE_VOD, seek);
          this.h5HLSplayer.pause();
          this.h5HLSplayer.status = MediaShareApe.PAUSE;
          this.controlBar.pause();
          this.controlBar.duration=listItem.duration||0;
          this.controlBar.changeVolume(listItem.mediaVolume);
        }
      }
    }
  }

  //媒体数据有更新，尝试停止
  _tryStopMediaHandler(_itemIdx) {
    /*    if (this.flashShareView && this.flashShareView.mediaId == _itemIdx) {
     UIControlApe.enabledBottomBar();
     UIControlApe.showBottomDocControlBar();
     this.currPlayMediaId = 0;
     this.flashShareView.stopMedia(_itemIdx);
     this._hideMediaShareBox();
     }*/
    loger.log("媒体数据有更新，尝试停止")
    if (this.h5HLSplayer && this.h5HLSplayer.mediaId == _itemIdx) {
      UIControlApe.enabledBottomBar();
      UIControlApe.showBottomDocControlBar();
      this.currPlayMediaId = 0;
      this.h5HLSplayer.rtmpURL = '';
      this.h5HLSplayer.mediaId = 0;
      this.h5HLSplayer.nodeId = 0;
      this.h5HLSplayer.stop();
      this.h5HLSplayer.pause();
      this.h5HLSplayer.status = MediaShareApe.STOP;
      if (this.h5HLSplayer.video) {
        this.h5HLSplayer.video.src = "";
      }
      this.controlBar.stop();
      this._hideMediaShareBox();
    }
  }

  //删除媒体鼠标事件
  _deleteListItemHandler(evt) {
    loger.log("删除媒体鼠标事件->", evt.target.id);
    let listItem = this.mediaShareFileList[parseInt(evt.target.id)];
    if (listItem) {
      let paramInfo = {
        "itemIdx": listItem.itemIdx,
        "fileId": listItem.fileId,
        "classId": ClassDataProxy.classId //课堂号
      };
      xdysdk.api("mediaSharedDelete", paramInfo);
    } else {
      loger.log("删除媒体鼠标事件---->媒体不存在");
    }
  }

  //调用SDK停止媒体共享播放
  _stopMeidaShare(_itemIdx) {
    loger.log('调用SDK停止媒体共享->', itemIdx);
    let itemIdx = parseInt(_itemIdx);
    if (itemIdx > 0) {
      let result = xdysdk.api("mediaSharedStop", {itemIdx: parseInt(itemIdx), status: 0});
    }
  }

  _playMeidaShare(_itemIdx) {
    loger.log('调用SDK开始媒体共享');
    let itemIdx = parseInt(_itemIdx);
    if (itemIdx > 0) {
      // let result = xdysdk.api("mediaSharedPlay", {itemIdx: parseInt(_itemIdx), status: 1});
      let result = xdysdk.api("mediaSharedPlay", {
        itemIdx: parseInt(_itemIdx),
        status: 1,
        seek: 0,
        mediaVolume: 30
      });
    }
  }

  //更新媒体的状态
  _updateMeidaShare(_itemIdx, _status, _seek, _mediaVolume) {
    loger.log('调用SDK -更新媒体共享状态->', _itemIdx, _status, _seek, _mediaVolume);
    if (ClassDataProxy.userRole == ClassDataProxy.USER_HOST && !ClassDataProxy.isRecordPlayBack) {
      let result = xdysdk.api("mediaSharedUpdate", {
        itemIdx: parseInt(_itemIdx),
        status: parseInt(_status),
        seek: parseInt(_seek),
        mediaVolume: parseInt(_mediaVolume)
      });
    }
  }

  //创建列表元素
  _creatListItemDiv(_id, _fileName, _owner) {
    let div = document.createElement("div");
    div.id = "doc_" + _id;

    //文件id
    let ico = document.createElement("label");
    ico.innerHTML = "&#xe674;";
    ico.className = "iconfont";
    div.appendChild(ico);

    //文件名称
    let nameDiv = document.createElement("label");
    nameDiv.innerText = "" + _fileName;
    nameDiv.title = "" + _fileName;
    nameDiv.onclick = this._clickListToSwitchBtnHandler.bind(this);
    nameDiv.id = _id;
    div.appendChild(nameDiv);

    //删除按钮
    let deleteBtn = document.createElement("label");
    deleteBtn.type = "button";
    // deleteBtn.value = "删除";
    deleteBtn.id = _id;
    deleteBtn.innerHTML = "&#xe673;";
    deleteBtn.className = "iconfont";
    deleteBtn.onclick = this._deleteListItemHandler.bind(this);
    div.appendChild(deleteBtn);

    return div;
  }

  clear() {
    loger.log("clear");
    this.mediaShareFileList = {};//媒体数据
    this._hideMediaShareBox();
    try {
      if (this.h5HLSplayer) {
        this.h5HLSplayer.rtmpURL = '';
        this.h5HLSplayer.mediaId = 0;
        this.h5HLSplayer.nodeId = 0;
        this.h5HLSplayer.stop();
        this.h5HLSplayer.pause();
        this.h5HLSplayer.status = MediaShareApe.STOP;
        if (this.h5HLSplayer.video) {
          this.h5HLSplayer.video.src = "";
        }
      }
      this._hideMediaShareBox();
    } catch (err) {
      loger.warn("clear", err.message);
    }
  }

  play() {
    loger.log("play");
    try {
      if (this.h5HLSplayer && ClassDataProxy.currentSceneTableId == ClassDataProxy.SCENE_MEDIA_SHARE) {
        this.h5HLSplayer.resume();
        this.h5HLSplayer.status = MediaShareApe.PLAY;
      }
    } catch (err) {
      loger.warn("clear", err.message);
    }

  }

  pause() {
    loger.log("pause");
    try {
      if (this.h5HLSplayer) {
        this.h5HLSplayer.pause()
        this.h5HLSplayer.status = MediaShareApe.PAUSE;
      }
    } catch (err) {
      loger.warn("clear", err.message);
    }

  }

  stop() {
    loger.log("stop");
    this.mediaShareFileList = {};//媒体数据
    this._hideMediaShareBox();
    try {
      if (this.h5HLSplayer) {
        this.currPlayMediaId = 0;
        this.h5HLSplayer.rtmpURL = '';
        this.h5HLSplayer.mediaId = 0;
        this.h5HLSplayer.nodeId = 0;
        this.h5HLSplayer.stop();
        this.h5HLSplayer.pause();
        this.h5HLSplayer.status = MediaShareApe.STOP;
        if (this.h5HLSplayer.video) {
          this.h5HLSplayer.video.src = "";
        }
      }
      this._hideMediaShareBox();
    } catch (err) {
      loger.warn("clear", err.message);
    }

  }
}
MediaShareApe.prototype.STOP = MediaShareApe.STOP = 0;
MediaShareApe.prototype.PLAY = MediaShareApe.PLAY = 1;
MediaShareApe.prototype.PAUSE = MediaShareApe.PAUSE = 2;
MediaShareApe.prototype.SCENE_MEDIA_SHARE_CHANGE = MediaShareApe.SCENE_MEDIA_SHARE_CHANGE = "scene_media_share_change";
export default MediaShareApe;


